==> phplist-2.10.5.tgz: lists/admin/lan/fr/send.php <==
<?php

## notes to translators:
# do not translate anything in square brackets: eg [RSS]

$lan = array (
  'noaccess' => 'Il n&rsquo;y a pas de message de ce type, ou alors vous n&rsquo;&ecirc;tes pas autoris&eacute;(e) &agrave; y acc&eacute;der',
  'htmlusedwarning' => 'Avertissement: Vous indiquez que le contenu n&rsquo;est pas du HTML, mais il y a des codes HTML dans votre message.  Ceci peut causer des erreurs',
  'adding' => 'Ajout',
  'longmimetype' => 'Le Mime Type d&eacute;passe les 255 caract&egrave;res, y&rsquo;a un probl&egrave;me',
  'addingattachment' => 'Pi&egrave;ce-jointe ajout&eacute;e ',
  'uploadfailed' => 'Le fichier t&eacute;l&eacute;charg&eacute; n&rsquo;a pas &eacute;t&eacute; correctement re&ccedil;u, le fichier est vide',
  'saved' => 'Message sauvegard&eacute;',
  'added' => 'Message ajout&eacute;',
  'queued' => 'Message mis dans la file d&rsquo;attente',
  'processqueue' => 'Envoyer les messages dans la File d&rsquo;attente',
  'errorsubject' => 'D&eacute;sol&eacute;, vous avez utilis&eacute; des caract&egrave;res invalides dans le champ Objet.',
  'errorfrom' => 'D&eacute;sol&eacute;, vous avez utilis&eacute; des caract&egrave;res invalides dans le champ Exp&eacute;diteur.',
  'enterfrom' => 'Merci de renseigner la ligne Exp&eacute;diteur.',
  'entermessage' => 'Merci de taper un message',
  'entersubject' => 'Merci de renseigner le champ Objet',
  'duplicateattribute' => 'Erreur: vous ne pouvez utiliser un attribut que pour une seule r&egrave;gle',
  'selectlist' => 'Veuillez s&eacute;lectionner la ou les liste(e) &agrave; qui vous voulez envoyer votre message',
  'notargetemail' => 'Il n&rsquo;y a pas d&rsquo;adresse email list&eacute;e o&ugrave; envoyer de message test.',
  'emailnotfound' => 'L&rsquo;adresse email pour envoyer un message test n&rsquo;a pas &eacute;t&eacute; trouv&eacute;e.',
  'sentemailto' => 'Message test envoy&eacute; &agrave;',
  'removedattachment' => 'Pi&egrave;ce-jointe supprim&eacute;e ',
  'existingcriteria' => 'Crit&egrave;res existants',
  'remove' => 'Supprimer',
  'calculating' => 'Calcul',
  'calculate' => 'Calculer',
  'content' => 'Contenu',
  'format' => 'Format',
  'attach' => 'Pi&egrave;ce-jointe',
  'scheduling' => 'Envoi programm&eacute;',
  'criteria' => 'Crit&egrave;res',
  'lists' => 'Listes',
  'unsavedchanges' => 'Attention! Vous n\'avez pas sauvegard&eacute; vos modifications\nCliquez OK pour continuer ou Annuler pour rester sur cette page\npour vous permettre de sauvegarder vos modifications.',
  'whatisprepare' => 'Qu&rsquo;est-ce que pr&eacute;parer un message',
  'subject' => 'Objet',
  'fromline' => 'Exp&eacute;diteur',
  'embargoeduntil' => 'Envoi diff&eacute;r&eacute; jusqu&rsquo;&agrave;',
  'repeatevery' => 'R&eacute;p&eacute;ter le message chaque',
  'norepetition' => 'pas de r&eacute;p&eacute;tition',
  'hour' => 'heure',
  'day' => 'jour',
  'week' => 'semaine',
  'repeatuntil' => 'R&eacute;p&eacute;ter Jusqu&rsquo;au',
  'format' => 'Format',
  'autodetect' => 'D&eacute;tecter automatiquement',
  'sendas' => 'Envoyer au format',
  'html' => 'HTML',
  'text' => 'texte',
  'pdf' => 'PDF',
//  'textandhtml' => 'Texte et HTML',//obsolete by bug 0009687
  'textandpdf' => 'Texte et PDF',
  'usetemplate' => 'Utiliser un Mod&egrave;le',
  'selectone' => 's&eacute;lectionner',
  'rssintro' => 'Si vous d&eacute;sirez utiliser ce message comme mod&egrave;le pour envoyer des fils RSS
s&eacute;lectionnez la fr&eacute;quence d&rsquo;envoi et utilisez [RSS] dans votre message pour indiquer o&ugrave; les entr&eacute;es du fil RSS doivent appara&icirc;tre.',
  'none' => 'aucune',
  'message' => 'Message',
  'expand' => 'd&eacute;compresser',
  'plaintextversion' => 'Version texte du message',
  'messagefooter' => 'Pied de page du message',
  'messagefooterexplanation' => 'Utilisez <b>[UNSUBSCRIBE]</b> pour inclure l&rsquo;URL de d&eacute;sinscription propre &agrave; chaque utilisateur.
    <br/>Utilisez <b>[PREFERENCES]</b> pour inclure l&rsquo;URL personnalis&eacute;e pour qu&rsquo;un utilisateur puisse mettre &agrave; jour ses donn&eacute;es personnelles',
  'addattachments' => 'Ajouter des pi&egrave;ce-jointes &agrave; votre message',
  'uploadlimits' => 'Le t&eacute;l&eacute;chargement est limit&eacute; par votre serveur comme suit',
  'maxtotaldata' => 'Taille maximale totale des donn&eacute;es envoy&eacute;es vers le serveur',
  'maxfileupload' => 'Taille maximale de chaque fichier pris individuellement',
  'currentattachments' => 'Pi&egrave;ce-jointes actuelles',
  'filename' => 'nom du fichier',
  'desc' => 'descr',# short for description
  'size' => 'taille',
  'file' => 'fichier',
  'del' => 'suppr', # short for delete
  'newattachment' => 'Nouvelle Pi&egrave;ce-Jointe',
  'addandsave' => 'Ajouter (et Sauver)',
  'pathtofile' => 'Chemin vers le fichier sur le serveur',
  'attachmentdescription' => 'Description de la pi&egrave;ce-jointe',
  'delchecked' => 'Supprimer les fichiers coch&eacute;s',
  'sendtestmessage' => 'Envoyer un Message de Test',
  'toemailaddresses' => ' aux adresses email',
  'sendtestexplain' => '(s&eacute;parez les adresses par des virgules - toutes les adresses doivent correspondre &agrave; des utilisateurs dans la base)',
  'criteriaexplanation' => '
        <p><b>S&eacute;lectionnez les crit&egrave;res d&rsquo;envoi pour ce message:</b>
        <ol>
        <li>pour utiliser un crit&egrave;re, cocher la case &lsquo;Utiliser ce crit&egrave;re&rsquo;
        <li>puis cliquer sur le bouton radio &agrave; c&ocirc;t&eacute; de l&rsquo;attribut que vous d&eacute;sirez utiliser
        <li>puis choisir les valeurs des attributs que vous voulez prendre en compte dans l&rsquo;envoi de votre message
        <i>Note:</i> Les messages seront envoy&eacute;s aux utilisateurs qui correspondent aux <i>Crit&egrave;re 1</i> <b>ET</b> <i>Crit&egrave;re 2</i> etc',
  'criterion' => 'Crit&egrave;re',
  'usethisone' => 'Utiliser ce crit&egrave;re',
  'or' => 'ou', # "alternative" ie this or this
  'is' => 'est',
  'isnot' => 'n&rsquo;est pas',
  'isbefore' => 'avant', # date and time wise
  'isafter' => 'apr&egrave;s', # date and time wise
  'nocriteria' => 'Il n&rsquo;y a pas encore d&rsquo;attributs disponibles pour vous permettre d&rsquo;envoyer un message.  Le message sera envoy&eacute; &agrave; tous les utilisateurs des listes s&eacute;lectionn&eacute;es',
  'checked' => 'Coch&eacute;s', # as for checkbox
  'unchecked' => 'Non coch&eacute;s', # as for checkbox
  'buggywithie' => 'Avertissement, cette fonctionnalit&eacute; pose encore des probl&egrave;mes avec IE (Internet Explorer).\nIl serait plus s&ucirc;r d&rsquo;utiliser Mozilla, Firefox ou Opera\nOu alors d&eacute;sactivez STACKED_ATTRIBUTE_SELECTION dans votre fichier de configuration', # Don't translate STACKED_ATTRIBUTE_SELECTION
  'matchallrules' => 'Utiliser toutes ces r&egrave;gles',
  'matchanyrules' => 'Utiliser n&rsquo;importe laquelle de ces r&egrave;gles',
  'addcriterion' => 'Ajouter Crit&egrave;re',
  'saveasdraft' => 'Sauver le message comme un brouillon',
  'savechanges' => 'Sauver les modifications',
  'selectattribute' => 's&eacute;lectionner un attribut',
  'dd-mm-yyyy' => 'jj-mm-aaaa', # it's essential that the format is the same (ie dd-mm-yyyy)

  # above is all from send_core

  'selectlists' => 'S&eacute;lectionnez les listes auxquelles vous d&eacute;sirez envoyer votre message',
  'alllists' => 'Toutes les listes',
  'listactive' => 'La liste est activ&eacute;e',
  'listnotactive' => 'La liste n&rsquo;est pas activ&eacute;e',
  'selectexcludelist' => 'S&eacute;lectionnez les listes &agrave; exclure.',
  'excludelistexplain' => 'Le message sera envoy&eacute; aux utilisateurs qui font partie des listes ci-dessus,
    &agrave; moins qu&rsquo;ils fassent partie d&rsquo;une des listes que vous s&eacute;lectionnez ici.',
  'nolistsavailable' => 'D&eacute;sol&eacute;, il n&rsquo;y a pour le moment aucune liste disponible.',
  'sendmessage' => 'Envoyer le message aux listes s&eacute;lectionn&eacute;es',
  'warnnopearhttprequest' => 'Vous essayez d&rsquo;envoyer un URL distant, mais  PEAR::HTTP/Request n&rsquo;est pas disponible, alors ceci &eacute;chouera',
  #
  'Misc' => 'Divers',
'email to alert when sending of this message starts' => 'adresse email &agrave; qui annoncer le d&eacute;but de l&rsquo;envoi de ce message',
'separate multiple with a comma' => 's&eacute;parer plusieurs adresses par une virgule',
'email to alert when sending of this message has finished' => 'adresse email &agrave; qui annoncer la fin de l&rsquo;envoi de ce message',
'separate multiple with a comma' => 's&eacute;parer plusieurs adresses par une virgule',

);

?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/fr/send.php <==
<?php

## notes to translators:
# do not translate anything in square brackets: eg [RSS]

$lan = array (
  'noaccess' => 'Il n&rsquo;y a pas de message de ce type, ou alors vous n&rsquo;&ecirc;tes pas autoris&eacute;(e) &agrave; y acc&eacute;der',
  'htmlusedwarning' => 'Avertissement: Vous indiquez que le contenu n&rsquo;est pas du HTML, mais il y a des codes HTML dans votre message.  Ceci peut causer des erreurs',
  'adding' => 'Ajout',
  'longmimetype' => 'Le Mime Type d&eacute;passe les 255 caract&egrave;res, y&rsquo;a un probl&egrave;me',
  'addingattachment' => 'Pi&egrave;ce-jointe ajout&eacute;e ',
  'uploadfailed' => 'Le fichier t&eacute;l&eacute;charg&eacute; n&rsquo;a pas &eacute;t&eacute; correctement re&ccedil;u, le fichier est vide',
  'saved' => 'Message sauvegard&eacute;',
  'added' => 'Message ajout&eacute;',
  'queued' => 'Message mis dans la file d&rsquo;attente',
  'processqueue' => 'Envoyer les messages dans la File d&rsquo;attente',
  'errorsubject' => 'D&eacute;sol&eacute;, vous avez utilis&eacute; des caract&egrave;res invalides dans le champ Objet.',
  'errorfrom' => 'D&eacute;sol&eacute;, vous avez utilis&eacute; des caract&egrave;res invalides dans le champ Exp&eacute;diteur.',
  'enterfrom' => 'Merci de renseigner la ligne Exp&eacute;diteur.',
  'entermessage' => 'Merci de taper un message',
  'entersubject' => 'Merci de renseigner le champ Objet',
  'duplicateattribute' => 'Erreur: vous ne pouvez utiliser un attribut que pour une seule r&egrave;gle',
  'selectlist' => 'Veuillez s&eacute;lectionner la ou les liste(e) &agrave; qui vous voulez envoyer votre message',
  'notargetemail' => 'Il n&rsquo;y a pas d&rsquo;adresse email list&eacute;e o&ugrave; envoyer de message test.',
  'emailnotfound' => 'L&rsquo;adresse email pour envoyer un message test n&rsquo;a pas &eacute;t&eacute; trouv&eacute;e.',
  'sentemailto' => 'Message test envoy&eacute; &agrave;',
  'removedattachment' => 'Pi&egrave;ce-jointe supprim&eacute;e ',
  'existingcriteria' => 'Crit&egrave;res existants',
  'remove' => 'Supprimer',
  'calculating' => 'Calcul',
  'calculate' => 'Calculer',
  'content' => 'Contenu',
  'format' => 'Format',
  'attach' => 'Pi&egrave;ce-jointe',
  'scheduling' => 'Envoi programm&eacute;',
  'criteria' => 'Crit&egrave;res',
  'lists' => 'Listes',
  'unsavedchanges' => 'Attention! Vous n\'avez pas sauvegard&eacute; vos modifications\nCliquez OK pour continuer ou Annuler pour rester sur cette page\npour vous permettre de sauvegarder vos modifications.',
  'whatisprepare' => 'Qu&rsquo;est-ce que pr&eacute;parer un message',
  'subject' => 'Objet',
  'fromline' => 'Exp&eacute;diteur',
  'embargoeduntil' => 'Envoi diff&eacute;r&eacute; jusqu&rsquo;&agrave;',
  'repeatevery' => 'R&eacute;p&eacute;ter le message chaque',
  'norepetition' => 'pas de r&eacute;p&eacute;tition',
  'hour' => 'heure',
  'day' => 'jour',
  'week' => 'semaine',
  'repeatuntil' => 'R&eacute;p&eacute;ter Jusqu&rsquo;au',
  'format' => 'Format',
  'autodetect' => 'D&eacute;tecter automatiquement',
  'sendas' => 'Envoyer au format',
  'html' => 'HTML',
  'text' => 'texte',
  'pdf' => 'PDF',
//  'textandhtml' => 'Texte et HTML',//obsolete by bug 0009687
  'textandpdf' => 'Texte et PDF',
  'usetemplate' => 'Utiliser un Mod&egrave;le',
  'selectone' => 's&eacute;lectionner',
  'rssintro' => 'Si vous d&eacute;sirez utiliser ce message comme mod&egrave;le pour envoyer des fils RSS
s&eacute;lectionnez la fr&eacute;quence d&rsquo;envoi et utilisez [RSS] dans votre message pour indiquer o&ugrave; les entr&eacute;es du fil RSS doivent appara&icirc;tre.',
  'none' => 'aucune',
  'message' => 'Message',
  'expand' => 'd&eacute;compresser',
  'plaintextversion' => 'Version texte du message',
  'messagefooter' => 'Pied de page du message',
  'messagefooterexplanation1' => 'Utilisez <b>[UNSUBSCRIBE]</b> pour inclure l&rsquo;URL de d&eacute;sinscription propre &agrave; chaque utilisateur.',
  'messagefooterexplanation2' => 'Utilisez <b>[PREFERENCES]</b> pour inclure l&rsquo;URL personnalis&eacute;e pour qu&rsquo;un utilisateur puisse mettre &agrave; jour ses donn&eacute;es personnelles',
  'messagefooterexplanation3' => 'Use <b>[FORWARD]</b> to add a personalised URL to forward the message to someone else.',
  'addattachments' => 'Ajouter des pi&egrave;ce-jointes &agrave; votre message',
  'uploadlimits' => 'Le t&eacute;l&eacute;chargement est limit&eacute; par votre serveur comme suit',
  'maxtotaldata' => 'Taille maximale totale des donn&eacute;es envoy&eacute;es vers le serveur',
  'maxfileupload' => 'Taille maximale de chaque fichier pris individuellement',
  'currentattachments' => 'Pi&egrave;ce-jointes actuelles',
  'filename' => 'nom du fichier',
  'desc' => 'descr',# short for description
  'size' => 'taille',
  'file' => 'fichier',
  'del' => 'suppr', # short for delete
  'newattachment' => 'Nouvelle Pi&egrave;ce-Jointe',
  'addandsave' => 'Ajouter (et Sauver)',
  'pathtofile' => 'Chemin vers le fichier sur le serveur',
  'attachmentdescription' => 'Description de la pi&egrave;ce-jointe',
  'delchecked' => 'Supprimer les fichiers coch&eacute;s',
  'sendtestmessage' => 'Envoyer un Message de Test',
  'toemailaddresses' => ' aux adresses email',
  'sendtestexplain' => '(s&eacute;parez les adresses par des virgules - toutes les adresses doivent correspondre &agrave; des utilisateurs dans la base)',
  'criteriaexplanation' => '
        <p><b>S&eacute;lectionnez les crit&egrave;res d&rsquo;envoi pour ce message:</b>
        <ol>
        <li>pour utiliser un crit&egrave;re, cocher la case &lsquo;Utiliser ce crit&egrave;re&rsquo;
        <li>puis cliquer sur le bouton radio &agrave; c&ocirc;t&eacute; de l&rsquo;attribut que vous d&eacute;sirez utiliser
        <li>puis choisir les valeurs des attributs que vous voulez prendre en compte dans l&rsquo;envoi de votre message
        <i>Note:</i> Les messages seront envoy&eacute;s aux utilisateurs qui correspondent aux <i>Crit&egrave;re 1</i> <b>ET</b> <i>Crit&egrave;re 2</i> etc',
  'criterion' => 'Crit&egrave;re',
  'usethisone' => 'Utiliser ce crit&egrave;re',
  'or' => 'ou', # "alternative" ie this or this
  'is' => 'est',
  'isnot' => 'n&rsquo;est pas',
  'isbefore' => 'avant', # date and time wise
  'isafter' => 'apr&egrave;s', # date and time wise
  'nocriteria' => 'Il n&rsquo;y a pas encore d&rsquo;attributs disponibles pour vous permettre d&rsquo;envoyer un message.  Le message sera envoy&eacute; &agrave; tous les utilisateurs des listes s&eacute;lectionn&eacute;es',
  'checked' => 'Coch&eacute;s', # as for checkbox
  'unchecked' => 'Non coch&eacute;s', # as for checkbox
  'buggywithie' => 'Avertissement, cette fonctionnalit&eacute; pose encore des probl&egrave;mes avec IE (Internet Explorer).\nIl serait plus s&ucirc;r d&rsquo;utiliser Mozilla, Firefox ou Opera\nOu alors d&eacute;sactivez STACKED_ATTRIBUTE_SELECTION dans votre fichier de configuration', # Don't translate STACKED_ATTRIBUTE_SELECTION
  'matchallrules' => 'Utiliser toutes ces r&egrave;gles',
  'matchanyrules' => 'Utiliser n&rsquo;importe laquelle de ces r&egrave;gles',
  'addcriterion' => 'Ajouter Crit&egrave;re',
  'saveasdraft' => 'Sauver le message comme un brouillon',
  'savechanges' => 'Sauver les modifications',
  'selectattribute' => 's&eacute;lectionner un attribut',
  'dd-mm-yyyy' => 'jj-mm-aaaa', # it's essential that the format is the same (ie dd-mm-yyyy)

  # above is all from send_core

  'selectlists' => 'S&eacute;lectionnez les listes auxquelles vous d&eacute;sirez envoyer votre message',
  'alllists' => 'Toutes les listes',
  'listactive' => 'La liste est activ&eacute;e',
  'listnotactive' => 'La liste n&rsquo;est pas activ&eacute;e',
  'selectexcludelist' => 'S&eacute;lectionnez les listes &agrave; exclure.',
  'excludelistexplain' => 'Le message sera envoy&eacute; aux utilisateurs qui font partie des listes ci-dessus,
    &agrave; moins qu&rsquo;ils fassent partie d&rsquo;une des listes que vous s&eacute;lectionnez ici.',
  'nolistsavailable' => 'D&eacute;sol&eacute;, il n&rsquo;y a pour le moment aucune liste disponible.',
  'sendmessage' => 'Envoyer le message aux listes s&eacute;lectionn&eacute;es',
  'warnnopearhttprequest' => 'Vous essayez d&rsquo;envoyer un URL distant, mais  PEAR::HTTP/Request n&rsquo;est pas disponible, alors ceci &eacute;chouera',
  #
  'Misc' => 'Divers',
'email to alert when sending of this message starts' => 'adresse email &agrave; qui annoncer le d&eacute;but de l&rsquo;envoi de ce message',
'separate multiple with a comma' => 's&eacute;parer plusieurs adresses par une virgule',
'email to alert when sending of this message has finished' => 'adresse email &agrave; qui annoncer la fin de l&rsquo;envoi de ce message',
'separate multiple with a comma' => 's&eacute;parer plusieurs adresses par une virgule',

);

?>
